program Compute_wavelet

  use sep
  
  implicit none
 
  complex, dimension(:), allocatable :: wz
  real,    dimension(:), allocatable :: wt

  integer :: ndim,nt,n3,i
  real    :: ot,dt,ow,dw,pi,o3,d3

  character(len=1024) :: label

  call sep_init(SOURCE)

  ndim=sep_dimension()

  call sep_get_data_axis_par("in",1,nt,ot,dt,label)
  call sep_get_data_axis_par("in",3,n3,o3,d3,label)

  write(0,*) 'INFO: There are ',n3,' filters'

  allocate(wz(nt),wt(nt))

  do i=1,n3
     write(0,*) 'INFO:    processing filter',i,'/',n3

     call sreed('in',wt,4*nt)

     wz=wt
     call slowft(wz,nt,-1,1)
     wz=1/(sqrt(abs(wz**2))*exp(cmplx(0,1)*atan2(aimag(wz),real(wz))))
     call slowft(wz,nt,1,nt)
     wt=cshift(real(wz),nt/2)
     
     call srite('out',wt,4*nt)

  end do
  write(0,*) 'INFO: done with processing'
  call to_history('o1',-dt*(nt-1)/2)
  call sep_close()
  
end program Compute_wavelet

subroutine slowft(c,nt,isign,scale)
  complex ::      c(nt)
  integer ::                 scale
  complex, allocatable :: t(:)
  real,    allocatable :: w(:)
  integer :: isign,nt,iw,it
  real    :: ow,dw,pi

  allocate(t(nt),w(nt))
  t=0.
  w=0.

  pi = 2.*ACOS(0.0)
  dw = 2.*pi/(nt)
  ow = 0.
  do iw = 1, nt
     w(iw) = ow  + (iw - 1) * dw
  end do

  do it=1,nt
     do iw=1,nt
        t(it)=t(it)+c(iw)*exp(cmplx(0,isign*w(iw)*(it-1)))
     end do
  end do

  t=t/scale
  c(1:nt)=t(1:nt)
  deallocate(t,w)

end subroutine slowft
